@@ -156,7 +156,7 @@ private Q_SLOTS:
         const auto res2 = getResources(m_appBackend->search(f));
         QCOMPARE(res2, res);
 
-        f.resourceUrl = QUrl(QStringLiteral("appstream://com.dosbox.DOSBox.desktop"));
+        f.resourceUrl = QUrl(QStringLiteral("appstream://com.dosbox.DOSBox"));
         const auto res3 = getResources(m_appBackend->search(f));
         QCOMPARE(res3, res);
     }
