@@ -34,6 +34,8 @@
 #include <QStringList>
 #include <QtConcurrentRun>
 
+#include <QCoroCore>
+
 #include <PackageKit/Daemon>
 #include <PackageKit/Details>
 #include <PackageKit/Offline>
@@ -46,11 +48,12 @@
 #include <optional>
 
 #include "config-paths.h"
-#include "libdiscover_backend_debug.h"
+#include "libdiscover_backend_packagekit_debug.h"
 #include "utils.h"
 #include <Category/Category.h>
 #include <resources/ResourcesModel.h>
 
+using namespace std::chrono_literals;
 using namespace Qt::StringLiterals;
 
 DISCOVER_BACKEND_PLUGIN(PackageKitBackend)
@@ -86,13 +89,13 @@ PackageOrAppId makePackageId(const QString &id)
     return {id, true};
 }
 
-PackageOrAppId makeResourceId(PackageKitResource *res)
+PackageOrAppId makeResourceId(PackageKitResource *resource)
 {
-    auto appstreamResource = qobject_cast<AppPackageKitResource *>(res);
+    auto appstreamResource = qobject_cast<AppPackageKitResource *>(resource);
     if (appstreamResource) {
         return {appstreamResource->appstreamId(), false};
     }
-    return {res->packageName(), true};
+    return {resource->packageName(), true};
 }
 
 template<typename T, typename W>
@@ -192,9 +195,8 @@ PackageKitBackend::PackageKitBackend(QObject *parent)
     });
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::isRunningChanged, this, &PackageKitBackend::checkDaemonRunning);
     connect(m_reviews.data(), &OdrsReviewsBackend::ratingsReady, this, [this] {
-        m_reviews->emitRatingFetched(this, kTransform<QList<AbstractResource *>>(m_packages.packages, [](AbstractResource *r) {
-                                         return r;
-                                     }));
+        const auto resources = m_packages.packages.values();
+        m_reviews->emitRatingFetched(this, resources);
     });
 
     auto proxyWatch = new QFileSystemWatcher(this);
@@ -212,10 +214,11 @@ PackageKitBackend::PackageKitBackend(QObject *parent)
     setWhenAvailable(
         PackageKit::Daemon::getTimeSinceAction(PackageKit::Transaction::RoleRefreshCache),
         [this](uint timeSince) {
-            if (timeSince > 3600)
+            if (timeSince > 3600) {
                 checkForUpdates();
-            else if (!PackageKit::Daemon::global()->offline()->upgradeTriggered())
+            } else if (!PackageKit::Daemon::global()->offline()->upgradeTriggered()) {
                 fetchUpdates();
+            }
             acquireFetching(false);
         },
         this);
@@ -261,8 +264,9 @@ void PackageKitBackend::updateProxy()
         bool useProxy = proxyConfig.readEntry<int>("ProxyType", 0) != 0;
 
         static bool everHad = useProxy;
-        if (!everHad && !useProxy)
+        if (!everHad && !useProxy) {
             return;
+        }
 
         everHad = useProxy;
 
@@ -282,15 +286,17 @@ bool PackageKitBackend::isFetching() const
 
 void PackageKitBackend::acquireFetching(bool f)
 {
-    if (f)
+    if (f) {
         m_isFetching++;
-    else
+    } else {
         m_isFetching--;
+    }
 
     if ((!f && m_isFetching == 0) || (f && m_isFetching == 1)) {
         Q_EMIT fetchingChanged();
-        if (m_isFetching == 0)
+        if (m_isFetching == 0) {
             Q_EMIT available();
+        }
     }
     Q_ASSERT(m_isFetching >= 0);
 }
@@ -319,7 +325,7 @@ void PackageKitBackend::reloadPackageList()
 
         // TODO
         // if (data.components.isEmpty()) {
-        //     qCDebug(LIBDISCOVER_BACKEND_LOG) << "empty appstream db";
+        //     qCDebug(LIBDISCOVER_BACKEND_PACKAGEKIT_LOG) << "empty appstream db";
         //     if (PackageKit::Daemon::backendName() == QLatin1String("aptcc") || PackageKit::Daemon::backendName().isEmpty()) {
         //         checkForUpdates();
         //     }
@@ -380,19 +386,19 @@ AppPackageKitResource *PackageKitBackend::addComponent(const AppStream::Componen
     Q_ASSERT(component.kind() != AppStream::Component::KindFirmware);
 
     auto appId = makeAppId(component.id());
-    AppPackageKitResource *res = qobject_cast<AppPackageKitResource *>(m_packages.packages.value(appId));
-    if (!res) {
-        res = qobject_cast<AppPackageKitResource *>(m_packagesToAdd.value(appId));
+    auto resource = qobject_cast<AppPackageKitResource *>(m_packages.packages.value(appId));
+    if (!resource) {
+        resource = qobject_cast<AppPackageKitResource *>(m_packagesToAdd.value(appId));
+    }
+    if (!resource) {
+        resource = new AppPackageKitResource(component, pkgNames.at(0), const_cast<PackageKitBackend *>(this));
+        m_packagesToAdd.insert(appId, resource);
     }
-    if (!res) {
-        res = new AppPackageKitResource(component, pkgNames.at(0), const_cast<PackageKitBackend *>(this));
-        m_packagesToAdd.insert(appId, res);
 
-    }
-    for (const QString &pkg : pkgNames) {
+    for (const auto &pkg : pkgNames) {
         m_packages.packageToApp[pkg] += component.id();
     }
-    return res;
+    return resource;
 }
 
 PKResolveTransaction *PackageKitBackend::resolvePackages(const QStringList &packageNames)
@@ -415,8 +421,9 @@ PKResolveTransaction *PackageKitBackend::resolvePackages(const QStringList &pack
 
 void PackageKitBackend::fetchUpdates()
 {
-    if (m_updater->isProgressing())
+    if (m_updater->isProgressing()) {
         return;
+    }
 
     PackageKit::Transaction *tUpdates = PackageKit::Daemon::getUpdates();
     connect(tUpdates, &PackageKit::Transaction::finished, this, &PackageKitBackend::getUpdatesFinished);
@@ -455,8 +462,9 @@ void PackageKitBackend::addPackage(PackageKit::Transaction::Info info, const QSt
         r = {pk};
         m_packagesToAdd.insert(makePackageId(packageName), pk);
     }
-    for (auto res : std::as_const(r))
-        static_cast<PackageKitResource *>(res)->addPackageId(info, packageId, arch);
+    for (auto resource : std::as_const(r)) {
+        static_cast<PackageKitResource *>(resource)->addPackageId(info, packageId, arch);
+    }
 }
 
 void PackageKitBackend::getPackagesFinished()
@@ -466,21 +474,22 @@ void PackageKitBackend::getPackagesFinished()
 
 void PackageKitBackend::includePackagesToAdd()
 {
-    if (m_packagesToAdd.isEmpty() && m_packagesToDelete.isEmpty())
+    if (m_packagesToAdd.isEmpty() && m_packagesToDelete.isEmpty()) {
         return;
+    }
 
     acquireFetching(true);
-    for (auto [id, res] : KeyValueRange(std::as_const(m_packagesToAdd))) {
-        m_packages.packages[id] = res;
+    for (auto [id, resource] : KeyValueRange(std::as_const(m_packagesToAdd))) {
+        m_packages.packages[id] = resource;
     }
     m_packagesToAdd.clear();
-    for (PackageKitResource *res : std::as_const(m_packagesToDelete)) {
-        const auto pkgs = m_packages.packageToApp.value(res->packageName(), {res->packageName()});
+    for (auto pkResource : std::as_const(m_packagesToDelete)) {
+        const auto pkgs = m_packages.packageToApp.value(pkResource->packageName(), {pkResource->packageName()});
         for (const auto &pkg : pkgs) {
-            auto res = m_packages.packages.take(makePackageId(pkg));
-            if (res) {
-                Q_EMIT resourceRemoved(res);
-                res->deleteLater();
+            auto resource = m_packages.packages.take(makePackageId(pkg));
+            if (resource) {
+                Q_EMIT resourceRemoved(resource);
+                resource->deleteLater();
             }
         }
     }
@@ -497,11 +506,13 @@ void PackageKitBackend::transactionError(PackageKit::Transaction::Error, const Q
 void PackageKitBackend::packageDetails(const PackageKit::Details &details)
 {
     const QSet<AbstractResource *> resources = resourcesByPackageName(PackageKit::Daemon::packageName(details.packageId()));
-    if (resources.isEmpty())
+    if (resources.isEmpty()) {
         qWarning() << "PackageKitBackend: Couldn't find package for" << details.packageId();
+        return;
+    }
 
-    for (AbstractResource *res : resources) {
-        qobject_cast<PackageKitResource *>(res)->setDetails(details);
+    for (auto resource : resources) {
+        qobject_cast<PackageKitResource *>(resource)->setDetails(details);
     }
 }
 
@@ -516,9 +527,9 @@ T PackageKitBackend::resourcesByAppNames(const W &appNames) const
     T ret;
     ret.reserve(appNames.size());
     for (const QString &name : appNames) {
-        AbstractResource *res = m_packages.packages.value(makeAppId(name));
-        if (res) {
-            ret += res;
+        auto resource = m_packages.packages.value(makeAppId(name));
+        if (resource) {
+            ret += resource;
         }
     }
     return ret;
@@ -533,22 +544,22 @@ T PackageKitBackend::resourcesByPackageNames(const W &pkgnames) const
         const QStringList app_names = m_packages.packageToApp.value(pkg_name, QStringList());
         if (app_names.isEmpty()) {
             auto pkgId = makePackageId(pkg_name);
-            PackageKitResource *res = qobject_cast<PackageKitResource *>(m_packages.packages.value(pkgId));
-            if (!res) {
-                res = m_packagesToAdd.value(pkgId);
+            auto resource = qobject_cast<PackageKitResource *>(m_packages.packages.value(pkgId));
+            if (!resource) {
+                resource = m_packagesToAdd.value(pkgId);
             }
-            if (res) {
-                ret += res;
+            if (resource) {
+                ret += resource;
             }
         } else {
             for (const QString &app_id : app_names) {
                 const auto appId = makeAppId(app_id);
-                AbstractResource *res = m_packages.packages.value(appId);
-                if (!res) {
-                    res = m_packagesToAdd.value(appId);
+                auto resource = m_packages.packages.value(appId);
+                if (!resource) {
+                    resource = m_packagesToAdd.value(appId);
                 }
-                if (res) {
-                    ret += res;
+                if (resource) {
+                    ret += resource;
                 } else {
                     ret += resourcesByComponents<T>(m_appdata->componentsByBundleId(AppStream::Bundle::KindPackage, pkg_name, false));
                 }
@@ -561,7 +572,7 @@ T PackageKitBackend::resourcesByPackageNames(const W &pkgnames) const
 void PackageKitBackend::checkForUpdates()
 {
     if (auto offline = PackageKit::Daemon::global()->offline(); offline->updateTriggered() || offline->upgradeTriggered()) {
-        qCDebug(LIBDISCOVER_BACKEND_LOG) << "Won't be checking for updates again, the system needs a reboot to apply the fetched offline updates.";
+        qCDebug(LIBDISCOVER_BACKEND_PACKAGEKIT_LOG) << "Won't be checking for updates again, the system needs a reboot to apply the fetched offline updates.";
         return;
     }
 
@@ -596,8 +607,9 @@ AppStream::ComponentBox PackageKitBackend::componentsById(const QString &id) con
     return comps;
 }
 
-static const auto needsResolveFilter = [](const StreamResult &res) {
-    return res.resource->state() == AbstractResource::Broken;
+static bool needsResolveFilter(const StreamResult &result)
+{
+    return result.resource->state() == AbstractResource::Broken;
 };
 
 class PKResultsStream : public ResultsStream
@@ -620,35 +632,35 @@ private:
 
 public:
     template<typename... Args>
-    [[nodiscard]] static QPointer<PKResultsStream> create(Args&& ...args)
+    [[nodiscard]] static QPointer<PKResultsStream> create(Args &&...args)
     {
         return new PKResultsStream(std::forward<Args>(args)...);
     }
 
-    void sendResources(const QVector<StreamResult> &res, bool waitForResolved = false)
+    void sendResources(const QVector<StreamResult> &resources, bool waitForResolved = false)
     {
-        if (res.isEmpty()) {
+        if (resources.isEmpty()) {
             finish();
             return;
         }
 
-        Q_ASSERT(res.size() == QSet(res.constBegin(), res.constEnd()).size());
-        const auto toResolve = kFilter<QVector<StreamResult>>(res, needsResolveFilter);
+        Q_ASSERT(resources.size() == QSet(resources.constBegin(), resources.constEnd()).size());
+        const auto toResolve = kFilter<QVector<StreamResult>>(resources, needsResolveFilter);
         if (!toResolve.isEmpty()) {
-            auto transaction = backend->resolvePackages(kTransform<QStringList>(toResolve, [](const StreamResult &res) {
-                return res.resource->packageName();
+            auto transaction = backend->resolvePackages(kTransform<QStringList>(toResolve, [](const StreamResult &result) {
+                return result.resource->packageName();
             }));
             if (waitForResolved) {
                 Q_ASSERT(transaction);
-                connect(transaction, &QObject::destroyed, this, [this, res] {
-                    Q_EMIT resourcesFound(res);
+                connect(transaction, &QObject::destroyed, this, [this, resources] {
+                    Q_EMIT resourcesFound(resources);
                     finish();
                 });
                 return;
             }
         }
 
-        Q_EMIT resourcesFound(res);
+        Q_EMIT resourcesFound(resources);
         finish();
     }
 
@@ -656,49 +668,67 @@ private:
     PackageKitBackend *const backend;
 };
 
+PKResultsStream *PackageKitBackend::deferredResultStream(const QString &streamName, std::function<void(PKResultsStream *)> callback)
+{
+    // NOTE: stream is a child of `this` so we don't have guard this backend object separately.
+    auto stream = PKResultsStream::create(this, streamName);
+
+    // Don't capture variables into a coroutine lambda, pass them in as arguments instead
+    // See https://devblogs.microsoft.com/oldnewthing/20211103-00/?p=105870
+    [](PackageKitBackend *self, QPointer<PKResultsStream> stream, std::function<void(PKResultsStream *)> callback) -> QCoro::Task<> {
+        if (self->m_appstreamInitialized) {
+            co_await QCoro::sleepFor(0ms);
+        } else {
+            co_await qCoro(self, &PackageKitBackend::loadedAppStream);
+        }
+        if (stream.isNull()) {
+            co_return;
+        }
+        callback(stream);
+    }(this, stream, std::move(callback));
+
+    return stream;
+}
+
 ResultsStream *PackageKitBackend::search(const AbstractResourcesBackend::Filters &filter)
 {
+    // In this method we are copying filters by value into capturing lambdas
+    // to avoid lifetime issues. Also coroutines should not be capturing, so
+    // we use nested lambdas with arguments instead of captures.
     if (!filter.resourceUrl.isEmpty()) {
         return findResourceByPackageName(filter.resourceUrl);
     } else if (!filter.extends.isEmpty()) {
-        auto stream = PKResultsStream::create(this, QStringLiteral("PackageKitStream-extends"));
-        auto f = [this, filter, stream] {
-            if (!stream) {
-                return;
-            }
+        return deferredResultStream(u"PackageKitStream-extends"_s, [this, filter = filter](PKResultsStream *stream) {
             const auto extendingComponents = m_appdata->componentsByExtends(filter.extends);
             auto resources = resultsByComponents(extendingComponents);
             stream->sendResources(resources, filter.state != AbstractResource::Broken);
-        };
-        runWhenInitialized(f, stream);
-        return stream;
+        });
     } else if (filter.state == AbstractResource::Upgradeable) {
         return new ResultsStream(QStringLiteral("PackageKitStream-upgradeable"),
                                  kTransform<QVector<StreamResult>>(upgradeablePackages())); // No need for it to be a PKResultsStream
     } else if (filter.state == AbstractResource::Installed) {
-        auto stream = PKResultsStream::create(this, QStringLiteral("PackageKitStream-installed"));
-        auto f = [this, stream, filter] {
-            if (!stream) {
-                return;
-            }
+        return deferredResultStream(u"PackageKitStream-installed"_s, [this, filter = filter](PKResultsStream *stream) {
             loadAllPackages();
+
             const auto toResolve = kFilter<QVector<AbstractResource *>>(m_packages.packages, needsResolveFilter);
 
-            auto installedAndNameFilter = [filter](AbstractResource *res) {
-                return res->state() >= AbstractResource::Installed && !qobject_cast<PackageKitResource *>(res)->isCritical()
-                    && (res->name().contains(filter.search, Qt::CaseInsensitive) || res->packageName().compare(filter.search, Qt::CaseInsensitive) == 0);
+            auto installedAndNameFilter = [filter](AbstractResource *resource) {
+                return resource->state() >= AbstractResource::Installed && !qobject_cast<PackageKitResource *>(resource)->isCritical()
+                    && (resource->name().contains(filter.search, Qt::CaseInsensitive)
+                        || resource->packageName().compare(filter.search, Qt::CaseInsensitive) == 0);
             };
             bool furtherSearch = false;
             if (!toResolve.isEmpty()) {
-                resolvePackages(kTransform<QStringList>(toResolve, [](AbstractResource *res) {
-                    return res->packageName();
+                resolvePackages(kTransform<QStringList>(toResolve, [](AbstractResource *resource) {
+                    return resource->packageName();
                 }));
                 connect(m_resolveTransaction, &PKResolveTransaction::allFinished, this, [stream, toResolve, installedAndNameFilter] {
                     const auto resolved = kFilter<QVector<AbstractResource *>>(toResolve, installedAndNameFilter);
-                    if (!resolved.isEmpty())
+                    if (!resolved.isEmpty()) {
                         Q_EMIT stream->resourcesFound(kTransform<QVector<StreamResult>>(resolved, [](auto resource) {
-                            return StreamResult{resource, 0};
+                            return StreamResult(resource, 0);
                         }));
+                    }
                     stream->finish();
                 });
                 furtherSearch = true;
@@ -706,46 +736,38 @@ ResultsStream *PackageKitBackend::search(const AbstractResourcesBackend::Filters
 
             const auto resolved = kFilter<QVector<AbstractResource *>>(m_packages.packages, installedAndNameFilter);
             if (!resolved.isEmpty()) {
-                QTimer::singleShot(0, this, [resolved, toResolve, stream]() {
-                    if (!resolved.isEmpty())
+                QTimer::singleShot(0, stream, [resolved, toResolve, stream]() {
+                    if (!resolved.isEmpty()) {
                         Q_EMIT stream->resourcesFound(kTransform<QVector<StreamResult>>(resolved, [](auto resource) {
-                            return StreamResult{resource, 0};
+                            return StreamResult(resource, 0);
                         }));
+                    }
 
-                    if (toResolve.isEmpty())
+                    if (toResolve.isEmpty()) {
                         stream->finish();
+                    }
                 });
                 furtherSearch = true;
             }
 
-            if (!furtherSearch)
+            if (!furtherSearch) {
                 stream->finish();
-        };
-        runWhenInitialized(f, stream);
-        return stream;
-    } else if (filter.search.isEmpty() && !filter.category) {
-        auto stream = PKResultsStream::create(this, QStringLiteral("PackageKitStream-all"));
-        auto f = [this, filter, stream] {
-            if (!stream) {
-                return;
             }
+        });
+    } else if (filter.search.isEmpty() && !filter.category) {
+        return deferredResultStream(u"PackageKitStream-all"_s, [this](PKResultsStream *stream) {
             loadAllPackages();
-            auto resources = kFilter<QVector<AbstractResource *>>(m_packages.packages, [](AbstractResource *res) {
-                return res->type() != AbstractResource::Technical && !qobject_cast<PackageKitResource *>(res)->isCritical()
-                    && !qobject_cast<PackageKitResource *>(res)->extendsItself();
+
+            auto resources = kFilter<QVector<AbstractResource *>>(m_packages.packages, [](AbstractResource *resource) {
+                auto pkResource = qobject_cast<PackageKitResource *>(resource);
+                return resource->type() != AbstractResource::Technical && pkResource && !pkResource->isCritical() && !pkResource->extendsItself();
             });
             stream->sendResources(kTransform<QVector<StreamResult>>(resources, [](auto resource) {
-                return StreamResult{resource, 0};
+                return StreamResult(resource, 0);
             }));
-        };
-        runWhenInitialized(f, stream);
-        return stream;
+        });
     } else {
-        auto stream = PKResultsStream::create(this, QStringLiteral("PackageKitStream-search"));
-        const auto f = [this, stream, filter]() {
-            if (!stream) {
-                return;
-            }
+        return deferredResultStream(u"PackageKitStream-search"_s, [this, filter = filter](PKResultsStream *stream) {
             AppStream::ComponentBox components(AppStream::ComponentBox::FlagNone);
             if (!filter.search.isEmpty()) {
                 components = m_appdata->search(filter.search);
@@ -756,10 +778,11 @@ ResultsStream *PackageKitBackend::search(const AbstractResourcesBackend::Filters
             }
 
             QSet<QString> ids;
-            kFilterInPlace<AppStream::ComponentBox>(components, [&ids](const AppStream::Component &comp) {
-                if (ids.contains(comp.id()))
+            kFilterInPlace<AppStream::ComponentBox>(components, [&ids](const AppStream::Component &component) {
+                if (ids.contains(component.id())) {
                     return false;
-                ids.insert(comp.id());
+                }
+                ids.insert(component.id());
                 return true;
             });
             if (!ids.isEmpty()) {
@@ -770,18 +793,7 @@ ResultsStream *PackageKitBackend::search(const AbstractResourcesBackend::Filters
             } else {
                 stream->finish();
             }
-        };
-        runWhenInitialized(f, stream);
-        return stream;
-    }
-}
-
-void PackageKitBackend::runWhenInitialized(const std::function<void()> &f, QObject *stream)
-{
-    if (!m_appstreamInitialized) {
-        connect(this, &PackageKitBackend::loadedAppStream, stream, f);
-    } else {
-        QTimer::singleShot(0, stream, f); // NOTE `stream` is a child of `this` so this transitively also depends on `this`
+        });
     }
 }
 
@@ -799,66 +811,60 @@ PKResultsStream *PackageKitBackend::findResourceByPackageName(const QUrl &url)
         }
     } else if (url.scheme() == QLatin1String("appstream")) {
         const auto appstreamIds = AppStreamUtils::appstreamIds(url);
-        if (appstreamIds.isEmpty())
+        if (appstreamIds.isEmpty()) {
             Q_EMIT passiveMessage(i18n("Malformed appstream url '%1'", url.toDisplayString()));
-        else {
-            auto stream = PKResultsStream::create(this, QStringLiteral("PackageKitStream-appstream-url"));
-            const auto f = [this, appstreamIds, stream]() {
-                if (!stream) {
-                    return;
-                }
+        } else {
+            return deferredResultStream(u"PackageKitStream-appstream-url"_s, [this, appstreamIds](PKResultsStream *stream) {
                 auto toSend = QSet<StreamResult>();
                 toSend.reserve(appstreamIds.size());
                 for (const auto &appstreamId : appstreamIds) {
-                    const auto comps = componentsById(appstreamId);
-                    if (comps.isEmpty()) {
+                    const auto components = componentsById(appstreamId);
+                    if (components.isEmpty()) {
                         continue;
                     }
-                    const auto resources = resultsByComponents(comps);
-                    for (const auto &r : resources) {
-                        toSend.insert(r);
+                    const auto resources = resultsByComponents(components);
+                    for (const auto &resource : resources) {
+                        toSend.insert(resource);
                     }
                 }
                 stream->sendResources(QList(toSend.constBegin(), toSend.constEnd()));
-            };
-            runWhenInitialized(f, stream);
-            return stream;
+            });
         }
     }
     return PKResultsStream::create(this, QStringLiteral("PackageKitStream-unknown-url"), QVector<StreamResult>{}).data();
 }
 
 template<typename T>
-T PackageKitBackend::resourcesByComponents(const AppStream::ComponentBox &comps) const
+T PackageKitBackend::resourcesByComponents(const AppStream::ComponentBox &components) const
 {
     T ret;
-    ret.reserve(comps.size());
+    ret.reserve(components.size());
     QSet<QString> done;
-    for (const auto &comp : comps) {
-        if (comp.packageNames().isEmpty() || done.contains(comp.id())) {
+    for (const auto &component : components) {
+        if (component.packageNames().isEmpty() || done.contains(component.id())) {
             continue;
         }
-        done += comp.id();
-        auto r = addComponent(comp);
+        done += component.id();
+        auto r = addComponent(component);
         Q_ASSERT(r);
         ret << r;
     }
     return ret;
 }
 
-QVector<StreamResult> PackageKitBackend::resultsByComponents(const AppStream::ComponentBox &comps) const
+QVector<StreamResult> PackageKitBackend::resultsByComponents(const AppStream::ComponentBox &components) const
 {
     QVector<StreamResult> ret;
-    ret.reserve(comps.size());
+    ret.reserve(components.size());
     QSet<QString> done;
-    for (const auto &comp : comps) {
-        if (comp.packageNames().isEmpty() ||  comp.kind() == AppStream::Component::KindFirmware || done.contains(comp.id())) {
+    for (const auto &component : components) {
+        if (component.packageNames().isEmpty() || component.kind() == AppStream::Component::KindFirmware || done.contains(component.id())) {
             continue;
         }
-        done += comp.id();
-        auto r = addComponent(comp);
+        done += component.id();
+        auto r = addComponent(component);
         Q_ASSERT(r);
-        ret << StreamResult{r, comp.sortScore()};
+        ret << StreamResult(r, component.sortScore());
     }
     return ret;
 }
@@ -870,40 +876,38 @@ bool PackageKitBackend::hasSecurityUpdates() const
 
 int PackageKitBackend::updatesCount() const
 {
-    if (auto offline = PackageKit::Daemon::global()->offline(); offline->updateTriggered() || offline->upgradeTriggered())
+    auto offline = PackageKit::Daemon::global()->offline();
+    if (offline->updateTriggered() || offline->upgradeTriggered()) {
         return 0;
+    }
 
-    int ret = 0;
     QSet<QString> packages;
     const auto toUpgrade = upgradeablePackages();
-    for (auto res : toUpgrade) {
-        const auto packageName = res->packageName();
-        if (packages.contains(packageName)) {
-            continue;
-        }
-        packages.insert(packageName);
-        ret += 1;
+    for (auto resource : toUpgrade) {
+        packages.insert(resource->packageName());
     }
-    return ret;
+    return packages.count();
 }
 
 Transaction *PackageKitBackend::installApplication(AbstractResource *app, const AddonList &addons)
 {
-    Transaction *t = nullptr;
+    Transaction *transaction = nullptr;
     if (!addons.addonsToInstall().isEmpty()) {
         QVector<AbstractResource *> appsToInstall = resourcesByPackageNames<QVector<AbstractResource *>>(addons.addonsToInstall());
-        if (!app->isInstalled())
+        if (!app->isInstalled()) {
             appsToInstall << app;
-        t = new PKTransaction(appsToInstall, Transaction::ChangeAddonsRole);
-    } else if (!app->isInstalled())
-        t = installApplication(app);
+        }
+        transaction = new PKTransaction(appsToInstall, Transaction::ChangeAddonsRole);
+    } else if (!app->isInstalled()) {
+        transaction = installApplication(app);
+    }
 
     if (!addons.addonsToRemove().isEmpty()) {
         const auto appsToRemove = resourcesByPackageNames<QVector<AbstractResource *>>(addons.addonsToRemove());
-        t = new PKTransaction(appsToRemove, Transaction::RemoveRole);
+        transaction = new PKTransaction(appsToRemove, Transaction::RemoveRole);
     }
 
-    return t;
+    return transaction;
 }
 
 Transaction *PackageKitBackend::installApplication(AbstractResource *app)
@@ -937,8 +941,8 @@ QSet<AbstractResource *> PackageKitBackend::upgradeablePackages() const
         }
         ret.unite(pkgs);
     }
-    return kFilter<QSet<AbstractResource *>>(ret, [](AbstractResource *res) {
-        return !static_cast<PackageKitResource *>(res)->extendsItself();
+    return kFilter<QSet<AbstractResource *>>(ret, [](AbstractResource *resource) {
+        return !static_cast<PackageKitResource *>(resource)->extendsItself();
     });
 }
 
@@ -953,8 +957,9 @@ void PackageKitBackend::addPackageToUpdate(PackageKit::Transaction::Info info, c
         return;
     }
 
-    if (info == PackageKit::Transaction::InfoSecurity)
+    if (info == PackageKit::Transaction::InfoSecurity) {
         m_hasSecurityUpdates = true;
+    }
 
     m_updatesPackageId += packageId;
     addPackage(info, packageId, summary, true);
@@ -978,13 +983,15 @@ void PackageKitBackend::getUpdatesFinished(PackageKit::Transaction::Exit, uint)
             },
             this);
         connect(this, &PackageKitBackend::available, a, &OneTimeAction::trigger);
-    } else
+    } else {
         Q_EMIT updatesCountChanged();
+    }
 
     if (!m_updater->isDistroUpgrade() && !PackageKit::Daemon::global()->offline()->upgradeTriggered()) {
         auto nextRelease = AppStreamIntegration::global()->getDistroUpgrade(m_appdata.get());
-        if (nextRelease)
+        if (nextRelease) {
             foundNewMajorVersion(*nextRelease);
+        }
     }
 }
 
@@ -1009,8 +1016,9 @@ void PackageKitBackend::foundNewMajorVersion(const AppStream::Release &release)
     // - No update to the current version are available or pending a reboot
     DiscoverAction *majorUpgrade = new DiscoverAction(QStringLiteral("system-upgrade-symbolic"), i18nc("@action: button", "Upgrade Now"), this);
     connect(majorUpgrade, &DiscoverAction::triggered, this, [this, release, upgradeVersion] {
-        if (m_updater->isProgressing())
+        if (m_updater->isProgressing()) {
             return;
+        }
 
         m_updatesPackageId.clear();
         m_updater->setProgressing(true);
@@ -1048,32 +1056,39 @@ void PackageKitBackend::foundNewMajorVersion(const AppStream::Release &release)
 // It's an optimisation as there's a bunch of allocations that happen from packageName
 // Having packageName return a QStringRef or a QStringView would fix this issue.
 // TODO Qt 6: Have packageName and similars return a QStringView
-static QStringView TransactionpackageName(const QString &packageID)
+static QStringView TransactionPackageName(const QString &packageID)
 {
     return QStringView(packageID).left(packageID.indexOf(QLatin1Char(';')));
 }
 
-bool PackageKitBackend::isPackageNameUpgradeable(const PackageKitResource *res) const
+bool PackageKitBackend::isPackageNameUpgradeable(const PackageKitResource *resource) const
 {
-    const QString name = res->packageName();
+    const QString name = resource->packageName();
     for (const QString &pkgid : m_updatesPackageId) {
-        if (TransactionpackageName(pkgid) == name)
+        if (TransactionPackageName(pkgid) == name) {
             return true;
+        }
     }
     return false;
 }
 
-QSet<QString> PackageKitBackend::upgradeablePackageId(const PackageKitResource *res) const
+QSet<QString> PackageKitBackend::upgradeablePackageId(const PackageKitResource *resource) const
 {
     QSet<QString> ids;
-    const QString name = res->packageName();
+    const QString name = resource->packageName();
     for (const QString &pkgid : m_updatesPackageId) {
-        if (TransactionpackageName(pkgid) == name)
+        if (TransactionPackageName(pkgid) == name) {
             ids.insert(pkgid);
+        }
     }
     return ids;
 }
 
+void PackageKitBackend::fetchDetails(const QString &pkgid)
+{
+    m_details.add(pkgid);
+}
+
 void PackageKitBackend::fetchDetails(const QSet<QString> &pkgid)
 {
     m_details.add(pkgid);
@@ -1093,8 +1108,9 @@ void PackageKitBackend::checkDaemonRunning()
 {
     if (!PackageKit::Daemon::isRunning()) {
         qWarning() << "PackageKit stopped running!";
-    } else
+    } else {
         updateProxy();
+    }
 }
 
 AbstractBackendUpdater *PackageKitBackend::backendUpdater() const
@@ -1120,8 +1136,9 @@ QString PackageKitBackend::displayName() const
 
 int PackageKitBackend::fetchingUpdatesProgress() const
 {
-    if (!m_refresher)
+    if (!m_refresher) {
         return 100;
+    }
 
     int percentage = m_refresher->percentage();
     if (percentage > 100) {
@@ -1161,3 +1178,4 @@ void PackageKitBackend::loadAllPackages()
 }
 
 #include "PackageKitBackend.moc"
+#include "moc_PackageKitBackend.cpp"
